@@ -4,7 +4,7 @@
 
 
 #if !defined(COMPRESS_ID)
-#define COMPRESS_ID		_LZO_ECONCAT2(DD_BITS,CLEVEL)
+#define COMPRESS_ID     LZO_CPP_ECONCAT2(DD_BITS,CLEVEL)
 #endif
 
 
@@ -16,10 +16,10 @@
 ************************************************************************/
 
 #define LZO_COMPRESS \
-	_LZO_ECONCAT3(lzo1c_,COMPRESS_ID,_compress)
+    LZO_CPP_ECONCAT3(lzo1c_,COMPRESS_ID,_compress)
 
 #define LZO_COMPRESS_FUNC \
-	_LZO_ECONCAT3(_lzo1c_,COMPRESS_ID,_compress_func)
+    LZO_CPP_ECONCAT3(_lzo1c_,COMPRESS_ID,_compress_func)
 
 
 
@@ -30,16 +30,11 @@
 const lzo_compress_t LZO_COMPRESS_FUNC = do_compress;
 
 LZO_PUBLIC(int)
-LZO_COMPRESS ( const lzo_byte *in,  lzo_uint  in_len,
-                     lzo_byte *out, lzo_uintp out_len,
+LZO_COMPRESS ( const lzo_bytep in,  lzo_uint  in_len,
+                     lzo_bytep out, lzo_uintp out_len,
                      lzo_voidp wrkmem )
 {
-#if defined(__LZO_QUERY_COMPRESS)
-	if (__LZO_IS_COMPRESS_QUERY(in,in_len,out,out_len,wrkmem))
-		return __LZO_QUERY_COMPRESS(in,in_len,out,out_len,wrkmem,D_SIZE,lzo_sizeof(lzo_dict_t));
-#endif
-
-	return _lzo1c_do_compress(in,in_len,out,out_len,wrkmem,do_compress);
+    return _lzo1c_do_compress(in,in_len,out,out_len,wrkmem,do_compress);
 }
 
 /*
