@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -34,8 +34,8 @@
 #ifndef __LZO_CONFIG1B_H
 #define __LZO_CONFIG1B_H
 
-#include <lzo1b.h>
 #include "lzo_conf.h"
+#include "lzo/lzo1b.h"
 
 
 /***********************************************************************
@@ -45,19 +45,19 @@
 /* run bits (4 - 5) - the compressor and the decompressor
  * must use the same value. */
 #if !defined(RBITS)
-#  define RBITS		5
+#  define RBITS     5
 #endif
 
 /* dictionary depth (0 - 6) - this only affects the compressor.
  * 0 is fastest, 6 is best compression ratio */
 #if !defined(DDBITS)
-#  define DDBITS	0
+#  define DDBITS    0
 #endif
 
 /* compression level (1 - 9) - this only affects the compressor.
  * 1 is fastest, 9 is best compression ratio */
 #if !defined(CLEVEL)
-#  define CLEVEL	1			/* fastest by default */
+#  define CLEVEL    1           /* fastest by default */
 #endif
 
 
@@ -79,12 +79,8 @@
 
 /* add a special code so that the decompressor can detect the
  * end of the compressed data block (overhead is 3 bytes per block) */
-#undef LZO_EOF_CODE
 #define LZO_EOF_CODE
 
-/* return -1 instead of copying if the data cannot be compressed */
-#undef LZO_RETURN_IF_NOT_COMPRESSIBLE
-
 
 /***********************************************************************
 // algorithm internal configuration
@@ -92,14 +88,14 @@
 
 /* choose the hashing strategy */
 #ifndef LZO_HASH
-#define LZO_HASH		LZO_HASH_LZO_INCREMENTAL_A
+#define LZO_HASH        LZO_HASH_LZO_INCREMENTAL_A
 #endif
 
 /* config */
-#define R_BITS			RBITS
-#define DD_BITS			DDBITS
+#define R_BITS          RBITS
+#define DD_BITS         DDBITS
 #ifndef D_BITS
-#define D_BITS			14
+#define D_BITS          14
 #endif
 
 
@@ -117,7 +113,6 @@
 //
 ************************************************************************/
 
-#include "lzo_util.h"
 #include "lzo1b_de.h"
 #include "stats1b.h"
 
