@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,7 +21,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
@@ -33,9 +34,8 @@
 #ifndef __LZO_CONFIG1F_H
 #define __LZO_CONFIG1F_H
 
-#include <lzo1f.h>
 #include "lzo_conf.h"
-#include "lzo_util.h"
+#include "lzo/lzo1f.h"
 
 
 /***********************************************************************
@@ -45,15 +45,15 @@
 #define LZO_EOF_CODE
 #undef LZO_DETERMINISTIC
 
-#define M2_MAX_OFFSET	0x0800
-#define M3_MAX_OFFSET	0x3fff
+#define M2_MAX_OFFSET   0x0800
+#define M3_MAX_OFFSET   0x3fff
 
-#define M2_MIN_LEN		3
-#define M2_MAX_LEN		8
-#define M3_MIN_LEN		3
-#define M3_MAX_LEN		33
+#define M2_MIN_LEN      3
+#define M2_MAX_LEN      8
+#define M3_MIN_LEN      3
+#define M3_MAX_LEN      33
 
-#define M3_MARKER		224
+#define M3_MARKER       224
 
 
 /***********************************************************************
@@ -61,15 +61,15 @@
 ************************************************************************/
 
 #ifndef MIN_LOOKAHEAD
-#define MIN_LOOKAHEAD		(M2_MAX_LEN + 1)
+#define MIN_LOOKAHEAD       (M2_MAX_LEN + 1)
 #endif
 
 #if defined(LZO_NEED_DICT_H)
 
 #ifndef LZO_HASH
-#define LZO_HASH			LZO_HASH_LZO_INCREMENTAL_A
+#define LZO_HASH            LZO_HASH_LZO_INCREMENTAL_A
 #endif
-#define DL_MIN_LEN			M2_MIN_LEN
+#define DL_MIN_LEN          M2_MIN_LEN
 #include "lzo_dict.h"
 
 #endif
@@ -79,6 +79,6 @@
 #endif /* already included */
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
 
