@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -38,11 +38,10 @@
 #  define LZO1X
 #endif
 
-#if !defined(__LZO_IN_MINILZO)
-#include <lzo1x.h>
-#endif
 #include "lzo_conf.h"
-#include "lzo_util.h"
+#if !defined(__LZO_IN_MINILZO)
+#include "lzo/lzo1x.h"
+#endif
 
 
 /***********************************************************************
@@ -52,30 +51,30 @@
 #define LZO_EOF_CODE
 #undef LZO_DETERMINISTIC
 
-#define M1_MAX_OFFSET	0x0400
+#define M1_MAX_OFFSET   0x0400
 #ifndef M2_MAX_OFFSET
-#define M2_MAX_OFFSET	0x0800
+#define M2_MAX_OFFSET   0x0800
 #endif
-#define M3_MAX_OFFSET	0x4000
-#define M4_MAX_OFFSET	0xbfff
+#define M3_MAX_OFFSET   0x4000
+#define M4_MAX_OFFSET   0xbfff
 
-#define MX_MAX_OFFSET	(M1_MAX_OFFSET + M2_MAX_OFFSET)
+#define MX_MAX_OFFSET   (M1_MAX_OFFSET + M2_MAX_OFFSET)
 
-#define M1_MIN_LEN		2
-#define M1_MAX_LEN		2
-#define M2_MIN_LEN		3
+#define M1_MIN_LEN      2
+#define M1_MAX_LEN      2
+#define M2_MIN_LEN      3
 #ifndef M2_MAX_LEN
-#define M2_MAX_LEN		8
+#define M2_MAX_LEN      8
 #endif
-#define M3_MIN_LEN		3
-#define M3_MAX_LEN		33
-#define M4_MIN_LEN		3
-#define M4_MAX_LEN		9
+#define M3_MIN_LEN      3
+#define M3_MAX_LEN      33
+#define M4_MIN_LEN      3
+#define M4_MAX_LEN      9
 
-#define M1_MARKER		0
-#define M2_MARKER		64
-#define M3_MARKER		32
-#define M4_MARKER		16
+#define M1_MARKER       0
+#define M2_MARKER       64
+#define M3_MARKER       32
+#define M4_MARKER       16
 
 
 /***********************************************************************
@@ -83,15 +82,15 @@
 ************************************************************************/
 
 #ifndef MIN_LOOKAHEAD
-#define MIN_LOOKAHEAD		(M2_MAX_LEN + 1)
+#define MIN_LOOKAHEAD       (M2_MAX_LEN + 1)
 #endif
 
 #if defined(LZO_NEED_DICT_H)
 
 #ifndef LZO_HASH
-#define LZO_HASH			LZO_HASH_LZO_INCREMENTAL_B
+#define LZO_HASH            LZO_HASH_LZO_INCREMENTAL_B
 #endif
-#define DL_MIN_LEN			M2_MIN_LEN
+#define DL_MIN_LEN          M2_MIN_LEN
 #include "lzo_dict.h"
 
 #endif
