@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -38,9 +38,10 @@
 #  define LZO1Z
 #endif
 
-#include <lzo1z.h>
+#include "lzo_conf.h"
+#include "lzo/lzo1z.h"
 
-#define M2_MAX_OFFSET	0x0700
+#define M2_MAX_OFFSET   0x0700
 #include "config1x.h"
 
 #endif /* already included */
