@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -26,13 +26,10 @@
 
 
 
-#include <lzoconf.h>
-#if !defined(LZO_99_UNSUPPORTED)
+#define COMPRESS_ID     99
 
-#define COMPRESS_ID		99
-
-#define DDBITS			3
-#define CLEVEL			9
+#define DDBITS          3
+#define CLEVEL          9
 
 
 /***********************************************************************
@@ -48,33 +45,33 @@
 ************************************************************************/
 
 static int
-_lzo1a_do_compress ( const lzo_byte *in,  lzo_uint  in_len,
-                           lzo_byte *out, lzo_uintp out_len,
+_lzo1a_do_compress ( const lzo_bytep in,  lzo_uint  in_len,
+                           lzo_bytep out, lzo_uintp out_len,
                            lzo_voidp wrkmem,
                            lzo_compress_t func )
 {
-	int r;
+    int r;
 
-	/* don't try to compress a block that's too short */
-	if (in_len <= 0)
-	{
-		*out_len = 0;
-		r = LZO_E_OK;
-	}
-	else if (in_len <= MIN_LOOKAHEAD + 1)
-	{
+    /* don't try to compress a block that's too short */
+    if (in_len <= 0)
+    {
+        *out_len = 0;
+        r = LZO_E_OK;
+    }
+    else if (in_len <= MIN_LOOKAHEAD + 1)
+    {
 #if defined(LZO_RETURN_IF_NOT_COMPRESSIBLE)
-		*out_len = 0;
-		r = LZO_E_NOT_COMPRESSIBLE;
+        *out_len = 0;
+        r = LZO_E_NOT_COMPRESSIBLE;
 #else
-		*out_len = STORE_RUN(out,in,in_len) - out;
-		r = (*out_len > in_len) ? LZO_E_OK : LZO_E_ERROR;
+        *out_len = pd(STORE_RUN(out,in,in_len), out);
+        r = (*out_len > in_len) ? LZO_E_OK : LZO_E_ERROR;
 #endif
-	}
-	else
-		r = func(in,in_len,out,out_len,wrkmem);
+    }
+    else
+        r = func(in,in_len,out,out_len,wrkmem);
 
-	return r;
+    return r;
 }
 
 
@@ -83,11 +80,11 @@ _lzo1a_do_compress ( const lzo_byte *in,  lzo_uint  in_len,
 ************************************************************************/
 
 #if !defined(COMPRESS_ID)
-#define COMPRESS_ID		_LZO_ECONCAT2(DD_BITS,CLEVEL)
+#define COMPRESS_ID     _LZO_ECONCAT2(DD_BITS,CLEVEL)
 #endif
 
 
-#define LZO_CODE_MATCH_INCLUDE_FILE		"lzo1a_cm.ch"
+#define LZO_CODE_MATCH_INCLUDE_FILE     "lzo1a_cm.ch"
 #include "lzo1b_c.ch"
 
 
@@ -96,10 +93,10 @@ _lzo1a_do_compress ( const lzo_byte *in,  lzo_uint  in_len,
 ************************************************************************/
 
 #define LZO_COMPRESS \
-	_LZO_ECONCAT3(lzo1a_,COMPRESS_ID,_compress)
+    LZO_CPP_ECONCAT3(lzo1a_,COMPRESS_ID,_compress)
 
 #define LZO_COMPRESS_FUNC \
-	_LZO_ECONCAT3(_lzo1a_,COMPRESS_ID,_compress_func)
+    LZO_CPP_ECONCAT3(_lzo1a_,COMPRESS_ID,_compress_func)
 
 
 /***********************************************************************
@@ -107,19 +104,13 @@ _lzo1a_do_compress ( const lzo_byte *in,  lzo_uint  in_len,
 ************************************************************************/
 
 LZO_PUBLIC(int)
-LZO_COMPRESS ( const lzo_byte *in,  lzo_uint  in_len,
-                     lzo_byte *out, lzo_uintp out_len,
+LZO_COMPRESS ( const lzo_bytep in,  lzo_uint  in_len,
+                     lzo_bytep out, lzo_uintp out_len,
                      lzo_voidp wrkmem )
 {
-#if defined(__LZO_QUERY_COMPRESS)
-	if (__LZO_IS_COMPRESS_QUERY(in,in_len,out,out_len,wrkmem))
-		return __LZO_QUERY_COMPRESS(in,in_len,out,out_len,wrkmem,D_SIZE,lzo_sizeof(lzo_dict_t));
-#endif
-
-	return _lzo1a_do_compress(in,in_len,out,out_len,wrkmem,do_compress);
+    return _lzo1a_do_compress(in,in_len,out,out_len,wrkmem,do_compress);
 }
 
-#endif
 
 /*
 vi:ts=4:et
