@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -56,19 +56,19 @@ extern const lzo_compress_t _lzo1b_99_compress_func;
 //
 ************************************************************************/
 
-LZO_EXTERN(lzo_byte *)
-_lzo1b_store_run ( lzo_byte * const oo, const lzo_byte * const ii,
-				   lzo_uint r_len);
+LZO_EXTERN(lzo_bytep )
+_lzo1b_store_run ( lzo_bytep const oo, const lzo_bytep const ii,
+                   lzo_uint r_len);
 
-#define STORE_RUN	_lzo1b_store_run
+#define STORE_RUN   _lzo1b_store_run
 
 
 lzo_compress_t _lzo1b_get_compress_func(int clevel);
 
-int _lzo1b_do_compress   ( const lzo_byte *in,  lzo_uint  in_len,
-								 lzo_byte *out, lzo_uintp out_len,
-								 lzo_voidp wrkmem,
-								 lzo_compress_t func );
+int _lzo1b_do_compress   ( const lzo_bytep in,  lzo_uint  in_len,
+                                 lzo_bytep out, lzo_uintp out_len,
+                                 lzo_voidp wrkmem,
+                                 lzo_compress_t func );
 
 
 #endif /* already included */
