@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -27,7 +27,7 @@
 
 #include "config1f.h"
 
-#undef LZO_TEST_DECOMPRESS_OVERRUN
-#define DO_DECOMPRESS		lzo1f_decompress
+#undef LZO_TEST_OVERRUN
+#define DO_DECOMPRESS       lzo1f_decompress
 
 #include "lzo1f_d.ch"
