@@ -2,7 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2002 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
    All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
@@ -26,12 +26,12 @@
 
 
 #define LZO_NEED_DICT_H
-#define D_BITS			12
-#define D_INDEX1(d,p)		d = DM((0x21*DX2(p,4,5)) >> 5)
-#define D_INDEX2(d,p)		d = d ^ D_MASK
+#define D_BITS          12
+#define D_INDEX1(d,p)       d = DM(DMUL(0x21,DX2(p,4,5)) >> 5)
+#define D_INDEX2(d,p)       d = d ^ D_MASK
 
 #include "config1x.h"
 
-#define DO_COMPRESS		lzo1x_1_12_compress
+#define DO_COMPRESS     lzo1x_1_12_compress
 
 #include "lzo1x_c.ch"
