@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,13 +21,13 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 
 #include "config1z.h"
 
-#define LZO_TEST_DECOMPRESS_OVERRUN
-#define DO_DECOMPRESS		lzo1z_decompress_safe
+#define LZO_TEST_OVERRUN
+#define DO_DECOMPRESS       lzo1z_decompress_safe
 
 #include "lzo1x_d.ch"
