@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,21 +21,21 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
+   http://www.oberhumer.com/opensource/lzo/
  */
 
 
 #include "lzo_conf.h"
-#include "lzo_util.h"
 
 
 /***********************************************************************
 // crc32 checksum
 // adapted from free code by Mark Adler <madler@alumni.caltech.edu>
-// see http://www.cdrom.com/pub/infozip/zlib/
+// see http://www.zlib.org/
 ************************************************************************/
 
-const lzo_uint32 _lzo_crc32_table[256] = {
+static const lzo_uint32 lzo_crc32_table[256] = {
   0x00000000L, 0x77073096L, 0xee0e612cL, 0x990951baL, 0x076dc419L,
   0x706af48fL, 0xe963a535L, 0x9e6495a3L, 0x0edb8832L, 0x79dcb8a4L,
   0xe0d5e91eL, 0x97d2d988L, 0x09b64c2bL, 0x7eb17cbdL, 0xe7b82d07L,
@@ -90,12 +91,19 @@ const lzo_uint32 _lzo_crc32_table[256] = {
 };
 
 
+LZO_PUBLIC(const lzo_uint32p)
+lzo_get_crc32_table(void)
+{
+    return lzo_crc32_table;
+}
+
+
 #if 1
 #define LZO_DO1(buf,i) \
-	crc = _lzo_crc32_table[((int)crc ^ buf[i]) & 0xff] ^ (crc >> 8)
+    crc = table[((int)crc ^ buf[i]) & 0xff] ^ (crc >> 8)
 #else
 #define LZO_DO1(buf,i) \
-	crc = _lzo_crc32_table[(unsigned char)((unsigned char)crc ^ buf[i])] ^ (crc >> 8)
+    crc = table[(unsigned char)((unsigned char)crc ^ buf[i])] ^ (crc >> 8)
 #endif
 #define LZO_DO2(buf,i)  LZO_DO1(buf,i); LZO_DO1(buf,i+1);
 #define LZO_DO4(buf,i)  LZO_DO2(buf,i); LZO_DO2(buf,i+2);
@@ -104,30 +112,44 @@ const lzo_uint32 _lzo_crc32_table[256] = {
 
 
 LZO_PUBLIC(lzo_uint32)
-lzo_crc32(lzo_uint32 c, const lzo_byte *buf, lzo_uint len)
+lzo_crc32(lzo_uint32 c, const lzo_bytep buf, lzo_uint len)
 {
-	lzo_uint32 crc = (c & LZO_0xffffffffL) ^ LZO_0xffffffffL;
+    lzo_uint32 crc;
+#undef table
+#if 1
+#  define table lzo_crc32_table
+#else
+   const lzo_uint32 * table = lzo_crc32_table;
+#endif
 
-	if (buf == NULL)
-		return 0;
+    if (buf == NULL)
+        return 0;
 
-	if (len >= 16) do
-	{
-		LZO_DO16(buf,0);
-		buf += 16;
-		len -= 16;
-	} while (len >= 16);
-	if (len != 0) do
-	{
-		LZO_DO1(buf,0);
-		buf += 1;
-		len -= 1;
-	} while (len > 0);
+    crc = (c & LZO_UINT32_C(0xffffffff)) ^ LZO_UINT32_C(0xffffffff);
+    if (len >= 16) do
+    {
+        LZO_DO16(buf,0);
+        buf += 16;
+        len -= 16;
+    } while (len >= 16);
+    if (len != 0) do
+    {
+        LZO_DO1(buf,0);
+        buf += 1;
+        len -= 1;
+    } while (len > 0);
 
-	return crc ^ LZO_0xffffffffL;
+    return crc ^ LZO_UINT32_C(0xffffffff);
+#undef table
 }
 
+#undef LZO_DO1
+#undef LZO_DO2
+#undef LZO_DO4
+#undef LZO_DO8
+#undef LZO_DO16
+
 
 /*
-vi:ts=4
+vi:ts=4:et
 */
