@@ -2,7 +2,8 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1996-2000 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
+   All Rights Reserved.
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -20,30 +21,37 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
    Markus F.X.J. Oberhumer
-   markus.oberhumer@jk.uni-linz.ac.at
+   <markus@oberhumer.com>
  */
 
 #include <stdio.h>
 
-int main()
+int main(int argc, char *argv[])
 {
-  unsigned char c;
-  int s;
+    unsigned char c;
+    int s;
 
-  c = (unsigned char) (1 << (8 * sizeof(char) - 1));
-  s = 8 * (int) (sizeof(int) - sizeof(char));
+    if (argc < 0 && argv == NULL)   /* avoid warning about unused args */
+        return 0;
 
-  printf("Integral promotion: ");
-  if ((c << s) > 0)
-  {
-    printf("Classic C (unsigned-preserving)\n");
-    printf("%d %d %u\n", c, s, c << s);
-    return 1;
-  }
-  else
-  {
-    printf("ANSI C (value-preserving)\n");
-    printf("%d %d %d\n", c, s, c << s);
-    return 0;
-  }
+    c = (unsigned char) (1 << (8 * sizeof(char) - 1));
+    s = 8 * (int) (sizeof(int) - sizeof(char));
+
+    printf("Integral promotion: ");
+    if ((c << s) > 0)
+    {
+        printf("Classic C (unsigned-preserving)\n");
+        printf("%d %d %uu\n", c, s, c << s);
+        return 1;
+    }
+    else
+    {
+        printf("ANSI C (value-preserving)\n");
+        printf("%d %d %d\n", c, s, c << s);
+        return 0;
+    }
 }
+
+/*
+vi:ts=4:et
+*/
