@@ -10,14 +10,15 @@
 ##  Description:
 ##      Remove timing values from a table created by table.pl
 ##
-##  Copyright (C) 1996-2014 Markus Franz Xaver Johannes Oberhumer
+##  Copyright (C) 1996-2005 Markus Franz Xaver Johannes Oberhumer
 ##
 ##---------------------------------------------------------------------------##
 
 
 while (<>) {
-    if (substr($_,56) =~ /^\s+[\d\.]+\s+[\d\.]+\s+\|\s*\n$/) {
-        substr($_,56) = "     0.000     0.000 |\n";
+
+    if (substr($_,52) =~ /^\s+[\d\.]+\s+[\d\.]+\s+\|\s*\n$/i) {
+        substr($_,52) = "      0.00      0.00 |\n";
     }
     print;
 }
